SnapCandidate class

A candidate alignment line (in world coordinates).

Constructors

SnapCandidate({required SnapKind kind, required SnapAxis axis, required double pos})
const

Properties

axis SnapAxis
final
hashCode int
The hash code for this object.
no setterinherited
kind SnapKind
final
pos double
For vertical lines: x = pos; for horizontal: y = pos.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited