SnapLine class

Constructors

SnapLine(SnapKind kind, SnapAxis axis, Rect2D extentWorld)
const

Properties

axis SnapAxis
final
extentWorld Rect2D
Thin rect to render as the guide (world coords).
final
hashCode int
The hash code for this object.
no setterinherited
kind SnapKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited