SnapResult class

Constructors

SnapResult(Vec2 deltaWorld, SnapAxis axis, double score, List<SnapLine> guides)
const

Properties

axis SnapAxis
final
deltaWorld Vec2
final
guides List<SnapLine>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

none → const SnapResult