CanvasAssetRef class sealed

Implementers

Properties

canonicalKey String
Stable key for generic maps/caches.
no setter
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
raw String
The trimmed source string as it appeared in the canvas document.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited