canonicalKey property

String get canonicalKey

Stable key for generic maps/caches.

This is intentionally generic. App-specific resolvers may choose a different internal cache key, for example using the payload of a known scheme such as media:<id>.

Implementation

String get canonicalKey;