CanvasFieldKey class final

Stable identity for a runtime-editable canvas field.

This is intentionally a value object rather than an enum:

  • canvas_core owns built-in runtime scene fields;
  • packages can define their own field keys without changing canvas_core;
  • field keys can be shared across editing, binding, serialization, and other higher-level systems without coupling those systems to each other.

Constructors

CanvasFieldKey(String value)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Stable serialized field id.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override