CanvasFieldKeyConverter class

Serializes CanvasFieldKey as its stable string value.

This lets generated JSON models store field keys as:

{ "field": "text.content" }

instead of object-shaped JSON.

Constructors

CanvasFieldKeyConverter()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromJson(String json) CanvasFieldKey
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson(CanvasFieldKey object) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited