CanvasFields class abstract final

Built-in field keys for properties that exist in the base canvas_core runtime scene model.

Packages should define their own CanvasFieldKey constants for fields that are not part of the base runtime scene model.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited