CanvasFileAssetRef class final

Local file reference.

This includes file:// URIs and path-like local strings.

Inheritance

Constructors

CanvasFileAssetRef({required String raw, required String path})
const

Properties

canonicalKey String
Stable key for generic maps/caches.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setterinherited
path String
final
raw String
The trimmed source string as it appeared in the canvas document.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited