CanvasFill class sealed
Single source-of-truth fill for runtime. No backward-compat: only accepts the new {type: ...} JSON shape.
- Implementers
Constructors
- CanvasFill.gradient(LinearGradientSpec grad)
-
constfactory
- CanvasFill.none()
-
constfactory
- CanvasFill.solid(int color)
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, Object?> json) → CanvasFill