CanvasSceneDocument class abstract
- Available extensions
- Annotations
-
- @freezed
Constructors
-
CanvasSceneDocument({@Size2DConverter() @Default.new(Size2D(740, 360)) Size2D artboardSize, @CanvasFillConverter() @JsonKey.new(required: true, disallowNullValue: true) required CanvasFill backgroundFill, @JsonKey.new(required: true, disallowNullValue: true) required double backgroundOpacity, @Default.new(<Node>[]) List<
Node> children}) -
constfactory
-
CanvasSceneDocument.fromJson(Map<
String, dynamic> json) -
factory
Properties
- artboardSize → Size2D
-
no setterinherited
- backgroundFill → CanvasFill
-
no setterinherited
- backgroundOpacity → double
-
no setterinherited
-
children
→ List<
Node> -
no setterinherited
-
copyWith
→ $CanvasSceneDocumentCopyWith<
CanvasSceneDocument> -
Create a copy of CanvasSceneDocument
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_CanvasSceneDocument value)) → TResult -
Available on CanvasSceneDocument, provided by the CanvasSceneDocumentPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_CanvasSceneDocument value)?) → TResult? -
Available on CanvasSceneDocument, provided by the CanvasSceneDocumentPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_CanvasSceneDocument value)?, {required TResult orElse()}) → TResult -
Available on CanvasSceneDocument, provided by the CanvasSceneDocumentPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(Size2D artboardSize, CanvasFill backgroundFill, double backgroundOpacity, List< Node> children)?, {required TResult orElse()}) → TResult -
Available on CanvasSceneDocument, provided by the CanvasSceneDocumentPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this CanvasSceneDocument to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(Size2D artboardSize, CanvasFill backgroundFill, double backgroundOpacity, List< Node> children)) → TResult -
Available on CanvasSceneDocument, provided by the CanvasSceneDocumentPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(Size2D artboardSize, CanvasFill backgroundFill, double backgroundOpacity, List< Node> children)?) → TResult? -
Available on CanvasSceneDocument, provided by the CanvasSceneDocumentPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited