CanvasSceneValidationIssue class final
One deterministic validation diagnostic for a CanvasSceneDocument.
code, path, and relatedPath are suitable for machine consumption. message is human-readable diagnostic text and should not be treated as a stable API contract.
Constructors
- CanvasSceneValidationIssue({required CanvasSceneValidationCode code, required String path, required String message, })
-
const
Properties
- code → CanvasSceneValidationCode
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- path → String
-
final
-
A second JSON Pointer location when the issue relates two scene values.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited