CanvasSchemeAssetRef class final

Opaque custom-scheme reference, such as:

  • media:<id>
  • asset:<path>
  • library:<id>
  • cms:<id>

canvas_core does not interpret the scheme. It only splits the syntax.

Inheritance

Constructors

CanvasSchemeAssetRef({required String raw, required String scheme, required String payload})
const

Properties

canonicalKey String
Stable key for generic maps/caches.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasPayload bool
no setter
isEmpty bool
no setterinherited
payload String
Trimmed text after the first ":".
final
raw String
The trimmed source string as it appeared in the canvas document.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheme String
Lower-cased URI scheme name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited