CanvasUrlAssetRef class final

Network URL reference.

Inheritance

Constructors

CanvasUrlAssetRef({required String raw, required Uri uri})
const

Properties

canonicalKey String
Stable key for generic maps/caches.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setterinherited
raw String
The trimmed source string as it appeared in the canvas document.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri Uri
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited