CanvasViewportPlanner class abstract final

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

plan({required Size2D artboard, required double targetW, required double targetH, Rect2D? bounds, double paddingPx = 0, double bleedPx = 0, CanvasFit fit = CanvasFit.contain, double? minUniformScale, double? maxUniformScale, bool tight = false, bool snappingEnabled = false, double pixelRatioForSnapping = 1.0}) CanvasViewportPlanResult
Plan a viewport transform for editor/thumb/export.