CanvasViewportTransform class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- recordingH → double
-
final
- recordingW → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaleX → double
-
final
- scaleY → double
-
final
- translateX → double
-
final
- translateY → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
snapTranslation(
double pixelRatio) → CanvasViewportTransform -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited