ComputedScene class final

Constructors

ComputedScene({required List<DrawItem> drawList, required Map<NodeId, Node> nodeById, required Map<NodeId, Matrix4> worldById, required Map<NodeId, Matrix4> inverseWorldById, required Map<NodeId, Rect2D> localBoundsById, required Map<NodeId, Rect2D> visualBoundsWorldById, required Map<NodeId, PathIR> pathIRById, required Map<NodeId, ImagePlacement> imagePlacementById, required Map<NodeId, IconTextPayload> iconTextById, required Map<NodeId, PathIR> iconPathIRById})
const

Properties

drawList List<DrawItem>
final
hashCode int
The hash code for this object.
no setterinherited
iconPathIRById Map<NodeId, PathIR>
final
iconTextById Map<NodeId, IconTextPayload>
final
imagePlacementById Map<NodeId, ImagePlacement>
final
inverseWorldById Map<NodeId, Matrix4>
final
localBoundsById Map<NodeId, Rect2D>
final
nodeById Map<NodeId, Node>
final
pathIRById Map<NodeId, PathIR>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visualBoundsWorldById Map<NodeId, Rect2D>
final
worldById Map<NodeId, Matrix4>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() NodeId
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited