fallbackElementIds property
Optional fallback ids when the preferred element is absent or has no bounds.
Null means use scene root children.
Implementation
final ContentBoundsFallbackSelector? fallbackElementIds;
Optional fallback ids when the preferred element is absent or has no bounds.
Null means use scene root children.
final ContentBoundsFallbackSelector? fallbackElementIds;