ContentBoundsSpec class
Runtime-owned spec for custom content-bounds computation.
A null ContentBoundsSpec means content-bounds are disabled.
Constructors
- ContentBoundsSpec({double paddingPx = 0, ContentBoundsPolicy policy = const ContentBoundsPolicy()})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- paddingPx → double
-
final
- policy → ContentBoundsPolicy
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited