CoreServices class

Constructors

CoreServices({required TextMeasurer textMeasurer, ImageIntrinsics? images, IconResolver? icons})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
icons IconResolver?
final
images ImageIntrinsics?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textMeasurer TextMeasurer
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited