DrawTextOp class

Inheritance

Constructors

DrawTextOp({required String text, required String family, required int weight, required double size, required Vec2 originBaselineCenter, double letterSpacing = 0.0, ResolvedLinearGradient? gradient, Color32? solid, double shadowOffset = 0})

Properties

family String
final
gradient ResolvedLinearGradient?
final
hashCode int
The hash code for this object.
no setterinherited
letterSpacing double
Additional spacing between characters in logical canvas units.
final
originBaselineCenter Vec2
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowOffset double
final
size double
final
solid Color32?
final
text String
final
weight int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited