ImageData class abstract

Annotations
  • @freezed

Constructors

ImageData({@NullableSize2DConverter() Size2D? size, String? sourcePath, @Default.new(ImageFit.contain) ImageFit fit, @Vec2Converter() @Default.new(Vec2(0.5, 0.5)) Vec2 align})
const
factory
ImageData.fromJson(Map<String, dynamic> json)
factory

Properties

align Vec2
no setterinherited
copyWith → $ImageDataCopyWith<ImageData>
Create a copy of ImageData with the given fields replaced by the non-null parameter values.
no setterinherited
fit ImageFit
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size2D?
no setterinherited
sourcePath String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ImageData to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited