ImageIntrinsics class abstract

Constructors

ImageIntrinsics()

Properties

hashCode int
The hash code for this object.
no setterinherited
onIntrinsicUpdated Stream<ElementId>
NEW: fire when an image’s intrinsic size becomes available or changes. The editor/runtime should listen and rebuild ops for that id.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

intrinsicSize(ElementId id) Size2D?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited