PathCmd class

Constructors

PathCmd.close()
factory
PathCmd.cubicTo(Vec2 c1, Vec2 c2, Vec2 p)
factory
PathCmd.lineTo(Vec2 p)
factory
PathCmd.moveTo(Vec2 p)
factory
PathCmd.quadTo(Vec2 c, Vec2 p)
factory

Properties

c1 Vec2?
final
c2 Vec2?
final
hashCode int
The hash code for this object.
no setterinherited
p Vec2
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verb PathVerb
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited