PathData class abstract

Annotations
  • @freezed

Constructors

PathData({@Vec2ListNullableConverter() @Default.new(<Vec2?>[]) List<Vec2?> points, @PathSourceConverter() PathSource? source, @CanvasFillConverter() @Default.new(CanvasFillNone()) CanvasFill fill, @Default.new(FillRule.nonZero) FillRule fillRule, @Default.new(0x00000000) Color32 strokeColor, @Default.new(4.0) double strokeWidth, @Default.new(StrokeCap.butt) StrokeCap strokeCap, @Default.new(StrokeJoin.miter) StrokeJoin strokeJoin, @Default.new(4.0) double miterLimit, @Default.new(<double>[]) List<double> dash})
const
factory
PathData.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PathDataCopyWith<PathData>
Create a copy of PathData with the given fields replaced by the non-null parameter values.
no setterinherited
dash List<double>
no setterinherited
fill CanvasFill
no setterinherited
fillRule FillRule
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
miterLimit double
no setterinherited
points List<Vec2?>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source PathSource?
no setterinherited
strokeCap StrokeCap
no setterinherited
strokeColor int
no setterinherited
strokeJoin StrokeJoin
no setterinherited
strokeWidth double
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PathData to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited