PathIR class

Canonical compiled representation used everywhere internally.

Constructors

PathIR(List<PathCmd> cmds, PathStyle style)
const

Properties

cmds List<PathCmd>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style PathStyle
final

Methods

localBounds({bool includeStroke = true}) Rect2D
Cheap local AABB (optionally includes stroke expansion)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited