Rect2D class

Available extensions

Constructors

Rect2D(double left, double top, double right, double bottom)
const
Rect2D.fromLTRB(double l, double t, double r, double b)
factory
Rect2D.fromLTWH(double l, double t, double w, double h)
factory

Properties

bottom double
final
center Vec2

Available on Rect2D, provided by the Rect2DX extension

no setter
hashCode int
The hash code for this object.
no setteroverride
height double
no setter
left double
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
final
width double
no setter

Methods

contains(Vec2 p) bool
inflate(double r) Rect2D

Available on Rect2D, provided by the Rect2DX extension

intersects(Rect2D o) bool

Available on Rect2D, provided by the Rect2DX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
translate(Vec2 d) Rect2D

Available on Rect2D, provided by the Rect2DX extension

Operators

operator ==(Object other) bool
The equality operator.
override