RegularPolygonSource class

Inheritance

Constructors

RegularPolygonSource(int sides, double r, {double rotation = 0})
const
RegularPolygonSource.fromJson(Map<String, Object?> m)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
r double
final
rotation double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sides int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited