RenderSnapshot class
Runtime render snapshot.
Constructors
-
RenderSnapshot({required CanvasSceneDocument scene, required ComputedScene computed, required List<
PaintOp> ops, required Rect2D? contentBounds}) -
const
Properties
- computed → ComputedScene
-
final
- contentBounds → Rect2D?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ops
→ List<
PaintOp> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scene → CanvasSceneDocument
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited