ResolvedIconPath class final
Vector-backed icon (future-proof). Contract for now: the returned PathData should be normalized to your icon origin convention (ideally centered around (0,0) like Text baseline-center behavior).
- Inheritance
-
- Object
- ResolvedIcon
- ResolvedIconPath
Constructors
- ResolvedIconPath(PathData path)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited