ResolvedIconText class final

Font-backed icon (glyph in a font family).

Inheritance

Constructors

ResolvedIconText({required String glyph, required String fontFamily, FontWeightNum fontWeight = 900})
const

Properties

fontFamily String
final
fontWeight int
final
glyph String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited