ResolvedLinearGradient class

Constructors

ResolvedLinearGradient(Vec2 start, Vec2 end, List<Color32> colors, List<double> stops)
const

Properties

colors List<Color32>
final
end Vec2
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start Vec2
final
stops List<double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited