sendToBack static method
Moves id to the back of its sibling stack.
Implementation
static CanvasSceneDocument sendToBack(CanvasSceneDocument doc, NodeId id) {
return _moveWithinCurrentParent(doc, id, targetIndexFor: (_, _) => 0);
}
Moves id to the back of its sibling stack.
static CanvasSceneDocument sendToBack(CanvasSceneDocument doc, NodeId id) {
return _moveWithinCurrentParent(doc, id, targetIndexFor: (_, _) => 0);
}