Size2D class

2D size (width/height).

Constructors

Size2D(double w, double h)
const
Size2D.fromJson(Map<String, dynamic> json)
Fail-fast: requires numeric w and h.
factory

Properties

h double
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
w double
final

Methods

copyWith({double? w, double? h}) Size2D
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

zero → const Size2D