Transform2D class abstract

Annotations
  • @freezed

Constructors

Transform2D({@Vec2Converter() @Default.new(Vec2.zero) Vec2 position, @Default.new(0.0) double rotationRad, @Vec2Converter() @Default.new(Vec2(1, 1)) Vec2 scale, @Default.new(OriginKind.center) OriginKind origin, @NullableVec2Converter() Vec2? customPivotPx})
const
factory
Transform2D.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $Transform2DCopyWith<Transform2D>
Create a copy of Transform2D with the given fields replaced by the non-null parameter values.
no setterinherited
customPivotPx Vec2?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
origin OriginKind
no setterinherited
position Vec2
no setterinherited
rotationRad double
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale Vec2
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Transform2D to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited