showBothGuidesWhenClose property
If true, when both axes are within tolerance we render both guides, but we still apply the nearest axis only (unless inner dual-axis triggers).
Implementation
final bool showBothGuidesWhenClose;
If true, when both axes are within tolerance we render both guides, but we still apply the nearest axis only (unless inner dual-axis triggers).
final bool showBothGuidesWhenClose;