CanvasIconData class abstract
- Annotations
-
- @freezed
Constructors
- CanvasIconData({required String iconRef, @Default.new(96.0) double sizePx, @CanvasFillConverter() @Default.new(CanvasFill.solid(0xFF111111)) CanvasFill fill, @Default.new(0) double shadowOffset})
-
constfactory
-
CanvasIconData.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $CanvasIconDataCopyWith<
CanvasIconData> -
Create a copy of CanvasIconData
with the given fields replaced by the non-null parameter values.
no setterinherited
- fill → CanvasFill
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconRef → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowOffset → double
-
no setterinherited
- sizePx → double
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this CanvasIconData to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited