CanvasImageAsset class abstract
Backing source and optional natural dimensions for a document image.
- Available extensions
- Annotations
-
- @freezed
Constructors
- CanvasImageAsset({required String sourceRef, @NullableSize2DConverter() Size2D? intrinsicSize})
-
constfactory
-
CanvasImageAsset.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $CanvasImageAssetCopyWith<
CanvasImageAsset> -
Create a copy of CanvasImageAsset
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- intrinsicSize → Size2D?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceRef → String
-
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_CanvasImageAsset value)) → TResult -
Available on CanvasImageAsset, provided by the CanvasImageAssetPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_CanvasImageAsset value)?) → TResult? -
Available on CanvasImageAsset, provided by the CanvasImageAssetPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_CanvasImageAsset value)?, {required TResult orElse()}) → TResult -
Available on CanvasImageAsset, provided by the CanvasImageAssetPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String sourceRef, Size2D? intrinsicSize)?, {required TResult orElse()}) → TResult -
Available on CanvasImageAsset, provided by the CanvasImageAssetPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this CanvasImageAsset to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String sourceRef, Size2D? intrinsicSize)) → TResult -
Available on CanvasImageAsset, provided by the CanvasImageAssetPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String sourceRef, Size2D? intrinsicSize)?) → TResult? -
Available on CanvasImageAsset, provided by the CanvasImageAssetPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited