CanvasRenderPipeline class
Reusable runtime render pipeline.
Runtime renders a prepared CanvasSceneDocument. Domain-specific extensions should prepare their scenes before calling this pipeline, or expose their own wrapper extension from their package.
- Available extensions
Constructors
- CanvasRenderPipeline({required TextMeasurer textMeasurer, ImageIntrinsics? images, IconResolver? icons})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
CanvasSceneDocument scene, {ContentBoundsSpec? contentBounds, TextMeasureCache? textMeasureCache}) → RenderSnapshot -
buildCanonical(
CanvasSceneDocument scene, {ContentBoundsSpec? contentBounds, TextMeasureCache? textMeasureCache}) → RenderSnapshot -
Available on CanvasRenderPipeline, provided by the CanvasRenderPipelineCanonical extension
-
createServices(
{TextMeasureCache? textMeasureCache}) → CoreServices - Builds the service bundle used by runtime compute and paint planning.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited