CanvasRenderPipeline class

Reusable runtime render pipeline.

Runtime renders an already-prepared CanvasSceneDocument. Domain-specific preparation belongs outside this class and may use services before delegating the prepared scene to build.

Constructors

CanvasRenderPipeline({required TextMeasurer textMeasurer, ImageIntrinsics? images, IconResolver? icons})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
services CoreServices
Stable service bundle shared by scene preparation and final rendering.
final

Methods

build(CanvasSceneDocument scene, {ContentBoundsSpec? contentBounds}) RenderSnapshot
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited