createServices method
Builds the service bundle used by runtime compute and paint planning.
Extension packages can use this to prepare a scene with exactly the same service dependencies before delegating back to build.
Implementation
CoreServices createServices({TextMeasureCache? textMeasureCache}) {
return CoreServices(
tm: _textMeasurer,
images: _images,
icons: _icons,
textMeasureCache: textMeasureCache ?? TextMeasureCache(),
);
}