CanvasViewportPlanResult class
Extra sizing info for export tight mode.
Constructors
- CanvasViewportPlanResult({required CanvasViewportTransform transform, required double outputW, required double outputH})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputH → double
-
final
- outputW → double
-
Final logical output size (pre pixelRatio) used for recordingW/H math.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transform → CanvasViewportTransform
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited