ComputedScene class final

Constructors

ComputedScene({required List<DrawItem> drawList, required Map<ElementId, Node> nodeById, required Map<ElementId, Matrix4> worldById, required Map<ElementId, Matrix4> inverseWorldById, required Map<ElementId, Rect2D> localBoundsById, required Map<ElementId, Rect2D> visualBoundsWorldById, required Map<ElementId, PathIR> pathIRById, required Map<ElementId, ImagePlacement> imagePlacementById, required Map<ElementId, ResolvedIconText> iconTextById, required Map<ElementId, PathIR> iconPathIRById})
const

Properties

drawList List<DrawItem>
final
hashCode int
The hash code for this object.
no setterinherited
iconPathIRById Map<ElementId, PathIR>
final
iconTextById Map<ElementId, ResolvedIconText>
final
imagePlacementById Map<ElementId, ImagePlacement>
final
inverseWorldById Map<ElementId, Matrix4>
final
localBoundsById Map<ElementId, Rect2D>
final
nodeById Map<ElementId, Node>
final
pathIRById Map<ElementId, PathIR>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visualBoundsWorldById Map<ElementId, Rect2D>
final
worldById Map<ElementId, Matrix4>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() ElementId
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited