DrawItem class final
Properties
-
groupStack
→ List<
NodeId> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- leafId → NodeId
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → NodeId -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited