DrawItem class final

Constructors

DrawItem({required ElementId leafId, required List<ElementId> groupStack})
const

Properties

groupStack List<ElementId>
final
hashCode int
The hash code for this object.
no setterinherited
leafId ElementId
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() ElementId
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited