GroupBehaviorRef class abstract
Generic runtime-owned behavior envelope for optional group semantics.
Core runtime owns only this neutral container.
Optional packs own the meaning of type + version + data.
- Annotations
-
- @freezed
Constructors
-
GroupBehaviorRef({required String type, @Default.new(1) int version, @Default.new(<String, dynamic>{}) Map<
String, dynamic> data}) -
constfactory
-
GroupBehaviorRef.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $GroupBehaviorRefCopyWith<
GroupBehaviorRef> -
Create a copy of GroupBehaviorRef
with the given fields replaced by the non-null parameter values.
no setterinherited
-
data
→ Map<
String, dynamic> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
no setterinherited
- version → int
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this GroupBehaviorRef to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited