Properties
-
align
→ Vec2
-
no setterinherited
-
copyWith
→ $ImageDataCopyWith<ImageData>
-
Create a copy of ImageData
with the given fields replaced by the non-null parameter values.
no setterinherited
-
fit
→ ImageFit
-
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
size
→ Size2D?
-
no setterinherited
-
sourcePath
→ String?
-
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Serializes this ImageData to a JSON map.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited