ImageIntrinsics class abstract interface

Synchronous intrinsic-image lookup used by core scene computation.

Resource loading and change notifications belong to the host/runtime layer. Core only needs the latest intrinsic size available for an ElementId.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

intrinsicSize(ElementId id) Size2D?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited