NodeEditingX extension
Common immutable edits that preserve node identity and tree structure.
Structural operations such as changing node IDs or replacing group children are intentionally not part of this public editing surface.
- on
Methods
-
withHidden(
) → Node -
Available on Node, provided by the NodeEditingX extension
-
withLocked(
bool locked) → Node -
Available on Node, provided by the NodeEditingX extension
-
withName(
String? name) → Node -
Available on Node, provided by the NodeEditingX extension
-
withXf(
Transform2D xf) → Node -
Available on Node, provided by the NodeEditingX extension