NodeGeometry class final
Constructors
- NodeGeometry(CoreServices services)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- services → CoreServices
-
final
Methods
-
leafLocalBounds(
Node n, {Map< ElementId, PathIR> ? pathIRById, Map<ElementId, ImagePlacement> ? imagePlacementById, Map<ElementId, ResolvedIconText> ? iconTextById, Map<ElementId, PathIR> ? iconPathIRById}) → Rect2D? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited