PathStyle class
Constructors
Properties
-
dash
→ List<
double> ? -
final
- fill → Color32?
-
final
- fillRule → FillRule
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- miterLimit → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stroke → Color32?
-
final
- strokeCap → StrokeCap
-
final
- strokeJoin → StrokeJoin
-
final
- strokeWidth → double
-
final
Methods
-
copyWith(
{Color32? fill, FillRule? fillRule, Color32? stroke, double? strokeWidth, StrokeCap? strokeCap, StrokeJoin? strokeJoin, double? miterLimit, List< double> ? dash}) → PathStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited