SceneRenderBuilder typedef
SceneRenderBuilder =
RenderSnapshot Function(CanvasRenderPipeline pipeline, CanvasSceneDocument scene, {ContentBoundsSpec? contentBounds, TextMeasureCache? textMeasureCache})
Shared render-builder seam used by editors, thumbnails, exporters, and extension packages.
The input scene is a runtime scene that is ready for this builder's preparation/rendering rules. The default builder renders it directly. Custom builders may prepare it further before delegating to the runtime pipeline.
Implementation
typedef SceneRenderBuilder =
RenderSnapshot Function(
CanvasRenderPipeline pipeline,
CanvasSceneDocument scene, {
ContentBoundsSpec? contentBounds,
TextMeasureCache? textMeasureCache,
});