TextData class abstract
- Annotations
-
- @freezed
Constructors
- TextData({required String text, required String fontFamily, required FontWeightNum fontWeight, required double fontSize, @Default.new(0) int letterSpacing, @CanvasFillConverter() @Default.new(CanvasFill.solid(0xFF111111)) CanvasFill fill, @Default.new(0) double shadowOffset})
-
constfactory
-
TextData.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $TextDataCopyWith<
TextData> -
Create a copy of TextData
with the given fields replaced by the non-null parameter values.
no setterinherited
- fill → CanvasFill
-
no setterinherited
- fontFamily → String
-
no setterinherited
- fontSize → double
-
no setterinherited
- fontWeight → int
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- letterSpacing → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowOffset → double
-
no setterinherited
- text → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this TextData to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited